@@ -27,11 +27,12 @@
 #include <string.h>
 #include <limits.h>
 
-#include <glib/glist.h>
+#include <glib.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
 #include <brasero-volume.h>
+#include <canberra-gtk.h>
 
 #include "sj-error.h"
 #include "sj-extracting.h"
@@ -592,6 +593,12 @@ on_main_window_focus_in (GtkWidget * widget, GdkEventFocus * event, gpointer dat
 static void
 finished_actions (void)
 {
+  /* Trigger a sound effect */
+  ca_gtk_play_for_widget (main_window, 0,
+    CA_PROP_EVENT_ID, "complete-media-rip",
+    CA_PROP_EVENT_DESCRIPTION, _("CD rip complete"),
+    NULL);
+  
   /* Trigger glowing effect after copy */
   g_signal_connect (G_OBJECT (main_window), "focus-in-event",
                     G_CALLBACK (on_main_window_focus_in),  NULL);
@@ -892,12 +899,13 @@ sanitize_path (const char* str, const char* filesystem_type)
  * %tn -- track number (i.e 8)
  * %tN -- track number, zero padded (i.e 08)
  * %tt -- track title
+ * %tT -- track title (lowercase)
  * %ta -- track artist
  * %tA -- track artist (lowercase)
  * %ts -- track artist sortname
  * %tS -- track artist sortname (lowercase)
- * %dn -- disc number (i.e 6)
- * %dN -- disc number, zero padded (i.e 06)
+ * %dn -- disc and track number (i.e Disk 2 - 6, or 6)
+ * %dN -- disc number, zero padded (i.e d02t06, or 06)
  */
 char*
 filepath_parse_pattern (const char* pattern, const TrackDetails *track)
