@@ -63,13 +63,13 @@ static const FilePattern path_patterns[] = {
 };
 
 static const FilePattern file_patterns[] = {
-  {N_("Number - Title"), "%tN - %tt"},
+  {N_("Number - Title"), "%dn - %tt"},
   {N_("Track Title"), "%tt"},
   {N_("Track Artist - Track Title"), "%ta - %tt"},
   {N_("Track Artist (sortable) - Track Title"), "%ts - %tt"},
-  {N_("Number. Track Artist - Track Title"), "%tN. %ta - %tt"},
+  {N_("Number. Track Artist - Track Title"), "%dN. %ta - %tt"},
   /* {N_("Number. Track Artist (sortable) - Track Title"), "%tN. %ts - %tt"}, */
-  {N_("Number-Track Artist-Track Title (lowercase)"), "%tN-%tA-%tT"},
+  {N_("Number-Track Artist-Track Title (lowercase)"), "%dN-%tA-%tT"},
   /* {N_("Number-Track Artist (sortable)-Track Title (lowercase)"), "%tN-%tS-%tT"}, */
   {NULL, NULL}
 };
@@ -134,6 +134,9 @@ void prefs_path_option_changed (GtkComboBox *combo, gpointer user_data)
   gint active;
   const char* pattern;
   active = gtk_combo_box_get_active (combo);
+  if (active == -1)
+    return;
+
   pattern = path_patterns[active].pattern;
   if (pattern) {
     gconf_client_set_string (gconf_client, GCONF_PATH_PATTERN, pattern, NULL);
@@ -145,6 +148,9 @@ void prefs_file_option_changed (GtkComboBox *combo, gpointer user_data)
   gint active;
   const char* pattern;
   active = gtk_combo_box_get_active (combo);
+  if (active == -1)
+    return;
+
   pattern = file_patterns[active].pattern;
   if (pattern) {
     gconf_client_set_string (gconf_client, GCONF_FILE_PATTERN, pattern, NULL);
